from tkinter import *
from tkinter import ttk

import matplotlib.pyplot as plt
import networkx as nx
from matplotlib.backends.backend_tkagg import FigureCanvasTkAgg

import Main_menu


class Scatter:
    """this class let user select 2 data from Combobox
    and plot the scatter plot"""

    def __init__(self, root, data):
        self.root = root
        self.data = data
        # call function
        self.scatter_frame()

    def show(self):
        """create scatter plot graph from data choose by user"""
        self.plotsc.destroy()
        self.plotsc = LabelFrame(self.root,
                                 bg="#C1CDCD")
        self.plotsc.pack(side=TOP, padx=50)
        fig_sca, sc1 = plt.subplots(figsize=(7, 6))
        plt.scatter(self.data[self.combo1.get()], self.data[self.combo2.get()],
                    color='blue', marker='o')
        plt.xlabel(self.combo1.get())
        plt.ylabel(self.combo2.get())
        plt.title(
            f'relationship of {self.combo1.get()} and {self.combo2.get()}')
        canvas_dis = FigureCanvasTkAgg(fig_sca, master=self.plotsc)
        canvas_dis.draw()
        canvas_dis.get_tk_widget().pack()

    def menu(self):
        """clear the screen and return to main menu"""
        self.scatter.destroy()
        self.scatter1.destroy()
        self.plotsc.destroy()
        Main_menu.Menu(self.root)

    def scatter_frame(self):
        """function for user to select data from combobox and call"""
        # frame for make title of this function
        self.scatter = LabelFrame(self.root,
                                  bg="#C1CDCD")
        self.scatter.pack(side=TOP, padx=50)

        self.manu_frame_title = Label(self.scatter,
                                      text="relationship between the Menu 1 and Menu 2 by scatter plot",
                                      font=("Goudy Old Style", 20), bg="white",
                                      fg="#5856a0", padx=10, pady=30, )
        self.manu_frame_title.grid(padx=10, pady=10,
                                   sticky="w")

        # frame for Combobox left
        self.scatter1 = LabelFrame(self.root,
                                   bg="#C1CDCD")
        self.scatter1.pack(side=TOP, padx=50)
        self.combo1 = ttk.Combobox(self.scatter1,
                                   font=("Times New Roman", 15),
                                   width=28,
                                   state="readonly")
        self.combo1['values'] = (
            "Average WiFi speed", "Co-working spaces",
            "Average price of buying a coffee",
            "Average price of taxi (per km)", "After-work drinks",
            "bedroom apartment per month", "meal at a local")
        self.combo1.grid(row=1, column=0, padx=16, pady=10, sticky="w")

        # frame for Combobox right
        self.combo2 = ttk.Combobox(self.scatter1,
                                   font=("Times New Roman", 15),
                                   width=28,
                                   state="readonly")
        self.combo2['values'] = (
            "Average WiFi speed", "Co-working spaces",
            "Average price of buying a coffee",
            "Average price of taxi (per km)", "After-work drinks",
            "bedroom apartment per month", "meal at a local")
        self.combo2.grid(row=1, column=1, padx=16, pady=10, sticky="w")

        # button to show the graph after selection
        Button(self.scatter1, text="Click",
               command=self.show).grid(row=2, column=0, padx=0,
                                       pady=10)

        # button to return to menu_title
        Button(self.scatter1, text="Back",
               command=self.menu).grid(row=2, column=1, padx=0,
                                       pady=10)

        # frame for plot graph
        self.plotsc = LabelFrame(self.root,
                                 bg="#C1CDCD")
        self.plotsc.pack(side=TOP, padx=50)


class Require_graph:
    """show the requirement graph distribution and everyday graph(scatter)"""

    def __init__(self, root, data):
        self.root = root
        self.data = data
        self.graph()

    def graph_to_main_menu(self):
        """clear the page and return to manu title"""
        self.menu.destroy()
        Main_menu.Menu(self.root)

    def graph(self):
        """plot distribution graph and everyday graph"""
        # distribution graph
        self.menu = LabelFrame(self.root,
                               bg="#C1CDCD")
        self.menu.pack(padx=50, pady=100)

        fig_dis, da1 = plt.subplots(figsize=(5, 6))
        da1.hist(self.data["Average price of taxi (per km)"], bins=10,
                 edgecolor='black')
        da1.set_xlabel('Average price (pound)')
        da1.set_ylabel('Frequency')
        da1.set_title('Distribution of Average price of taxi (per km)')
        canvas_dis = FigureCanvasTkAgg(fig_dis, master=self.menu)
        canvas_dis.draw()
        canvas_dis.get_tk_widget().pack(side=LEFT)

        # scatter plot
        fig_scat, sa = plt.subplots(figsize=(5, 6))
        sa.scatter(self.data["bedroom apartment per month"],
                   self.data["meal at a local"], color='blue', marker='o')
        sa.set_title('relationship of bedroom apartment and meal at a local')
        sa.set_xlabel('bedroom apartment per month')
        sa.set_ylabel('meal at a local')
        canvas_scat = FigureCanvasTkAgg(fig_scat, master=self.menu)
        canvas_scat.draw()
        canvas_scat.get_tk_widget().pack(side=RIGHT)

        Button(self.menu, text="Back",
               command=self.graph_to_main_menu, pady=300).pack(
            side=BOTTOM)


class Network_graph:
    """class for plot network graph to Finding the most affordable
     travel programme for drinker"""

    def __init__(self, root, data):
        self.root = root
        self.data = data
        self.draw()

    def back_to_menu(self):
        """clear the page and return to manu title"""
        self.frame1.destroy()
        self.frame2.destroy()
        self.frame3.destroy()
        Main_menu.Menu(self.root)

    def draw(self):
        """draw network graph"""
        # title of the graph
        self.frame1 = LabelFrame(self.root,
                                 bg="#C1CDCD")
        self.frame1.pack(side=TOP, pady=10)
        self.manu_frame_title = Label(self.frame1,
                                      text="Finding the most affordable travel programme for drinker",
                                      font=("Goudy Old Style", 20), bg="white",
                                      fg="#5856a0", padx=10, pady=30, )
        self.manu_frame_title.grid(padx=10, pady=10,
                                   sticky="w")

        # frame for graph
        self.frame2 = LabelFrame(self.root,
                                 bg="#C1CDCD")
        self.frame2.pack(side=TOP, pady=20)

        # plot network graph
        fig, ax = plt.subplots(figsize=(7, 4))
        self.data = self.data[self.data["Ranking"] <= 20]
        self.G = nx.Graph()

        self.G.add_nodes_from(self.data["Country"])

        edges = []
        pos = nx.circular_layout(self.G)
        for i in range(len(self.data)):
            for j in range(i + 1, len(self.data)):
                if (int(self.data["After-work drinks"][i]) - int(
                        self.data["After-work drinks"][j])) > 0:
                    edges.append(
                        (self.data["Country"][i], self.data["Country"][j], (
                                int(self.data["After-work drinks"][i]) - int(
                            self.data["After-work drinks"][
                                j]))))

        self.G.add_weighted_edges_from(edges, width="weight")
        weight = nx.get_edge_attributes(self.G, "weight")
        nx.draw_networkx(self.G, pos, ax=ax, with_labels=True,
                         node_color='lightblue', edge_color='gray')
        ax.set_title('Node = country , Edges = After-work drinks')
        nx.draw_networkx_edges(self.G, pos, edge_color=(0, 0, 1))
        nx.draw(self.G, pos, with_labels=True)
        nx.draw_networkx_edge_labels(self.G, pos, edge_labels=weight,
                                     font_size=7)

        # put network graph in tkinter
        canvas_net = FigureCanvasTkAgg(fig, master=self.frame2)
        canvas_net.draw()
        canvas_net.get_tk_widget().pack()

        # frame for return button
        self.frame3 = LabelFrame(self.root,
                                 bg="#C1CDCD")
        self.frame3.pack(side=TOP, pady=0)
        # return to menu button
        Button(self.frame3, text="back", command=self.back_to_menu, pady=10,
               padx=20).pack(side=TOP)
